# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'nat_ui.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
#         MainWindow.resize(839, 737)
#         MainWindow.setMaximumSize(QtCore.QSize(16777215, 16777215))
#         MainWindow.setStyleSheet("\n"
# "background-color: rgb(59, 59, 59);\n"
# "border-radius:5px;")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_43.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_43.setSpacing(3)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.stackedWidget = QtWidgets.QStackedWidget(self.centralwidget)
        self.stackedWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.stackedWidget.setObjectName("stackedWidget")
        self.loading_page = QtWidgets.QWidget()
        self.loading_page.setObjectName("loading_page")
        self.verticalLayout_47 = QtWidgets.QVBoxLayout(self.loading_page)
        self.verticalLayout_47.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_47.setObjectName("verticalLayout_47")
        self.loading_frame = QtWidgets.QFrame(self.loading_page)
        self.loading_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.loading_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.loading_frame.setObjectName("loading_frame")
        self.loading_image = QtWidgets.QLabel(self.loading_frame)
        self.loading_image.setGeometry(QtCore.QRect(30, 170, 651, 331))
        self.loading_image.setText("")
        self.loading_image.setPixmap(QtGui.QPixmap("../../Downloads/lerone.jpg"))
        self.loading_image.setScaledContents(True)
        self.loading_image.setObjectName("loading_image")
        self.connection_label = QtWidgets.QLabel(self.loading_frame)
        self.connection_label.setGeometry(QtCore.QRect(240, 410, 241, 61))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(11)
        self.connection_label.setFont(font)
        self.connection_label.setStyleSheet("color: rgb(166, 166, 166);\n"
"background-color: rgba(59, 59, 59,50);")
        self.connection_label.setAlignment(QtCore.Qt.AlignCenter)
        self.connection_label.setObjectName("connection_label")
        self.loading_bar = QtWidgets.QProgressBar(self.loading_frame)
        self.loading_bar.setGeometry(QtCore.QRect(180, 320, 343, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.loading_bar.setFont(font)
        self.loading_bar.setStyleSheet("QProgressBar {\n"
"     border: none;\n"
"     color:white;\n"
"     background-color: rgba(79, 79, 79,70);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"     \n"
"    background-color: rgb(255, 65, 109);\n"
"     width: 20px;\n"
" }\n"
"\n"
"\n"
"")
        self.loading_bar.setProperty("value", 24)
        self.loading_bar.setAlignment(QtCore.Qt.AlignCenter)
        self.loading_bar.setObjectName("loading_bar")
        self.verticalLayout_47.addWidget(self.loading_frame)
        self.stackedWidget.addWidget(self.loading_page)
        self.login_page = QtWidgets.QWidget()
        self.login_page.setObjectName("login_page")
        self.login_header_frame = QtWidgets.QFrame(self.login_page)
        self.login_header_frame.setGeometry(QtCore.QRect(0, 0, 448, 24))
        self.login_header_frame.setMaximumSize(QtCore.QSize(16777215, 30))
        self.login_header_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_header_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_header_frame.setObjectName("login_header_frame")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.login_header_frame)
        self.horizontalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.left_header_content_4 = QtWidgets.QFrame(self.login_header_frame)
        self.left_header_content_4.setStyleSheet("background-color:none;")
        self.left_header_content_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.left_header_content_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_header_content_4.setObjectName("left_header_content_4")
        self.verticalLayout_44 = QtWidgets.QVBoxLayout(self.left_header_content_4)
        self.verticalLayout_44.setContentsMargins(9, 0, 0, 0)
        self.verticalLayout_44.setSpacing(3)
        self.verticalLayout_44.setObjectName("verticalLayout_44")
        self.label_4 = QtWidgets.QLabel(self.left_header_content_4)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.label_4.setFont(font)
        self.label_4.setStyleSheet("color: rgb(255, 23, 96);")
        self.label_4.setObjectName("label_4")
        self.verticalLayout_44.addWidget(self.label_4)
        self.horizontalLayout_24.addWidget(self.left_header_content_4)
        self.header_buttons_4 = QtWidgets.QFrame(self.login_header_frame)
        self.header_buttons_4.setMinimumSize(QtCore.QSize(15, 15))
        self.header_buttons_4.setMaximumSize(QtCore.QSize(400, 16777215))
        self.header_buttons_4.setStyleSheet("background-color:none;")
        self.header_buttons_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_buttons_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_buttons_4.setObjectName("header_buttons_4")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.header_buttons_4)
        self.horizontalLayout_23.setContentsMargins(300, 0, 0, 0)
        self.horizontalLayout_23.setSpacing(3)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.close_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.close_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.close_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.close_button_4.setStyleSheet("*{\n"
"border-none;\n"
"border-radius:8px;\n"
"background-color:red;\n"
"\n"
"\n"
"}")
        self.close_button_4.setText("")
        self.close_button_4.setObjectName("close_button_4")
        self.horizontalLayout_23.addWidget(self.close_button_4)
        self.restore_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.restore_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.restore_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.restore_button_4.setStyleSheet("*{\n"
"border-radius:8px;\n"
"\n"
"background-color: rgb(255, 142, 29);\n"
"\n"
"\n"
"}")
        self.restore_button_4.setText("")
        self.restore_button_4.setObjectName("restore_button_4")
        self.horizontalLayout_23.addWidget(self.restore_button_4)
        self.minimize_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.minimize_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.minimize_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.minimize_button_4.setStyleSheet("*{\n"
"border-radius:8px;\n"
"background-color:rgb(81, 244, 0)\n"
"\n"
"\n"
"}")
        self.minimize_button_4.setText("")
        self.minimize_button_4.setObjectName("minimize_button_4")
        self.horizontalLayout_23.addWidget(self.minimize_button_4)
        self.horizontalLayout_24.addWidget(self.header_buttons_4)
        self.login_body_frame = QtWidgets.QFrame(self.login_page)
        self.login_body_frame.setGeometry(QtCore.QRect(0, 33, 818, 671))
        self.login_body_frame.setMaximumSize(QtCore.QSize(818, 671))
        self.login_body_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_body_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_body_frame.setObjectName("login_body_frame")
        self.username_input = QtWidgets.QLineEdit(self.login_body_frame)
        self.username_input.setGeometry(QtCore.QRect(80, 130, 311, 41))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.username_input.setFont(font)
        self.username_input.setStyleSheet("*{\n"
"color:white;\n"
"background-color: rgba(20, 20, 20,40);\n"
"border-bottom:2px solid  rgb(255, 23, 96);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgba(20, 20, 20,100);\n"
"    border-bottom:2px solid  rgb(106, 59, 248);\n"
"}")
        self.username_input.setObjectName("username_input")
        self.password_input = QtWidgets.QLineEdit(self.login_body_frame)
        self.password_input.setGeometry(QtCore.QRect(80, 290, 321, 41))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.password_input.setFont(font)
        self.password_input.setStyleSheet("*{\n"
"color:white;\n"
"background-color: rgba(20, 20, 20,40);\n"
"border-bottom:2px solid  rgb(255, 23, 96);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgba(20, 20, 20,100);\n"
"    border-bottom:2px solid  rgb(106, 59, 248);\n"
"}")
        self.password_input.setEchoMode(QtWidgets.QLineEdit.PasswordEchoOnEdit)
        self.password_input.setObjectName("password_input")
        self.pushButton = QtWidgets.QPushButton(self.login_body_frame)
        self.pushButton.setGeometry(QtCore.QRect(130, 470, 211, 41))
        self.pushButton.setStyleSheet("*{\n"
"background-color: rgb(255, 23, 96);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgb(106, 59, 248);\n"
"}")
        self.pushButton.setObjectName("pushButton")
        self.image_background = QtWidgets.QLabel(self.login_body_frame)
        self.image_background.setGeometry(QtCore.QRect(-30, -20, 491, 701))
        self.image_background.setText("")
        self.image_background.setPixmap(QtGui.QPixmap("../../Downloads/esteb.jpg"))
        self.image_background.setScaledContents(True)
        self.image_background.setObjectName("image_background")
        self.image_background.raise_()
        self.username_input.raise_()
        self.password_input.raise_()
        self.pushButton.raise_()
        self.login_footer = QtWidgets.QFrame(self.login_page)
        self.login_footer.setGeometry(QtCore.QRect(0, 707, 141, 16))
        self.login_footer.setMaximumSize(QtCore.QSize(16777215, 20))
        self.login_footer.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_footer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_footer.setObjectName("login_footer")
        self.verticalLayout_45 = QtWidgets.QVBoxLayout(self.login_footer)
        self.verticalLayout_45.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_45.setSpacing(2)
        self.verticalLayout_45.setObjectName("verticalLayout_45")
        self.grip_label_4 = QtWidgets.QLabel(self.login_footer)
        self.grip_label_4.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.grip_label_4.setObjectName("grip_label_4")
        self.verticalLayout_45.addWidget(self.grip_label_4)
        self.stackedWidget.addWidget(self.login_page)
        self.bot_page = QtWidgets.QWidget()
        self.bot_page.setObjectName("bot_page")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.bot_page)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(3)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.main_frame = QtWidgets.QFrame(self.bot_page)
        self.main_frame.setStyleSheet("")
        self.main_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.main_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.main_frame.setObjectName("main_frame")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.main_frame)
        self.verticalLayout_29.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_29.setSpacing(3)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.header_frame = QtWidgets.QFrame(self.main_frame)
        self.header_frame.setMinimumSize(QtCore.QSize(400, 20))
        self.header_frame.setMaximumSize(QtCore.QSize(16777215, 40))
        self.header_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_frame.setObjectName("header_frame")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.header_frame)
        self.horizontalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_16.setSpacing(5)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.left_header_content = QtWidgets.QFrame(self.header_frame)
        self.left_header_content.setStyleSheet("background-color:none;")
        self.left_header_content.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.left_header_content.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_header_content.setObjectName("left_header_content")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.left_header_content)
        self.verticalLayout_30.setContentsMargins(9, 0, 0, 0)
        self.verticalLayout_30.setSpacing(3)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.label = QtWidgets.QLabel(self.left_header_content)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.label.setFont(font)
        self.label.setStyleSheet("color: rgb(255, 23, 96);")
        self.label.setObjectName("label")
        self.verticalLayout_30.addWidget(self.label)
        self.horizontalLayout_16.addWidget(self.left_header_content)
        self.header_buttons = QtWidgets.QFrame(self.header_frame)
        self.header_buttons.setMinimumSize(QtCore.QSize(15, 15))
        self.header_buttons.setMaximumSize(QtCore.QSize(400, 16777215))
        self.header_buttons.setStyleSheet("background-color:none;")
        self.header_buttons.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_buttons.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_buttons.setObjectName("header_buttons")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.header_buttons)
        self.horizontalLayout_17.setContentsMargins(300, 0, 0, 0)
        self.horizontalLayout_17.setSpacing(3)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.close_button = QtWidgets.QPushButton(self.header_buttons)
        self.close_button.setMinimumSize(QtCore.QSize(15, 15))
        self.close_button.setMaximumSize(QtCore.QSize(16, 16))
        self.close_button.setStyleSheet("*{\n"
"border-none;\n"
"border-radius:8px;\n"
"background-color:red;\n"
"\n"
"\n"
"}")
        self.close_button.setText("")
        self.close_button.setObjectName("close_button")
        self.horizontalLayout_17.addWidget(self.close_button)
        self.restore_button = QtWidgets.QPushButton(self.header_buttons)
        self.restore_button.setMinimumSize(QtCore.QSize(15, 15))
        self.restore_button.setMaximumSize(QtCore.QSize(16, 16))
        self.restore_button.setStyleSheet("*{\n"
"border-radius:8px;\n"
"\n"
"background-color: rgb(255, 142, 29);\n"
"\n"
"\n"
"}")
        self.restore_button.setText("")
        self.restore_button.setObjectName("restore_button")
        self.horizontalLayout_17.addWidget(self.restore_button)
        self.minimize_button = QtWidgets.QPushButton(self.header_buttons)
        self.minimize_button.setMinimumSize(QtCore.QSize(15, 15))
        self.minimize_button.setMaximumSize(QtCore.QSize(16, 16))
        self.minimize_button.setStyleSheet("*{\n"
"border-radius:8px;\n"
"background-color:rgb(81, 244, 0)\n"
"\n"
"\n"
"}")
        self.minimize_button.setText("")
        self.minimize_button.setObjectName("minimize_button")
        self.horizontalLayout_17.addWidget(self.minimize_button)
        self.horizontalLayout_16.addWidget(self.header_buttons)
        self.verticalLayout_29.addWidget(self.header_frame)
        self.body_frame = QtWidgets.QFrame(self.main_frame)
        self.body_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.body_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.body_frame.setObjectName("body_frame")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.body_frame)
        self.horizontalLayout_18.setContentsMargins(0, 0, 0, 2)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.progress_and_status_frame = QtWidgets.QFrame(self.body_frame)
        self.progress_and_status_frame.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.progress_and_status_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.progress_and_status_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.progress_and_status_frame.setObjectName("progress_and_status_frame")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.progress_and_status_frame)
        self.verticalLayout_31.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.hashtag_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.hashtag_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.hashtag_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.hashtag_frame.setObjectName("hashtag_frame")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.hashtag_frame)
        self.verticalLayout_32.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_32.setSpacing(3)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.hashtag_title = QtWidgets.QFrame(self.hashtag_frame)
        self.hashtag_title.setStyleSheet("border:2px solid  rgb(59, 59, 59);")
        self.hashtag_title.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.hashtag_title.setFrameShadow(QtWidgets.QFrame.Raised)
        self.hashtag_title.setObjectName("hashtag_title")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.hashtag_title)
        self.horizontalLayout_19.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_19.setSpacing(3)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.liked_label = QtWidgets.QLabel(self.hashtag_title)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.liked_label.setFont(font)
        self.liked_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.liked_label.setAlignment(QtCore.Qt.AlignCenter)
        self.liked_label.setObjectName("liked_label")
        self.horizontalLayout_19.addWidget(self.liked_label)
        self.verticalLayout_32.addWidget(self.hashtag_title)
        self.liked_progressBar = QtWidgets.QProgressBar(self.hashtag_frame)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.liked_progressBar.setFont(font)
        self.liked_progressBar.setStyleSheet("QProgressBar {\n"
"     border: 1px solid grey;\n"
"     border-radius: 2px;\n"
"     color:white;\n"
"     background-color: rgb(79, 79, 79);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"         background-color: rgb(17, 120, 255);\n"
"     width: 20px;\n"
" }\n"
"\n"
"\n"
"")
        self.liked_progressBar.setProperty("value", 24)
        self.liked_progressBar.setAlignment(QtCore.Qt.AlignCenter)
        self.liked_progressBar.setObjectName("liked_progressBar")
        self.verticalLayout_32.addWidget(self.liked_progressBar)
        self.like_listWidget = QtWidgets.QListWidget(self.hashtag_frame)
        font = QtGui.QFont()
        font.setFamily("Segoe UI Semibold")
        font.setBold(True)
        font.setWeight(75)
        self.like_listWidget.setFont(font)
        self.like_listWidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.like_listWidget.setTabKeyNavigation(False)
        self.like_listWidget.setWordWrap(True)
        self.like_listWidget.setObjectName("like_listWidget")
        item = QtWidgets.QListWidgetItem()
        self.like_listWidget.addItem(item)
        self.verticalLayout_32.addWidget(self.like_listWidget)
        self.verticalLayout_31.addWidget(self.hashtag_frame)
        self.content_separator_line = QtWidgets.QFrame(self.progress_and_status_frame)
        self.content_separator_line.setMaximumSize(QtCore.QSize(16777215, 1))
        self.content_separator_line.setStyleSheet("background-color:grey;")
        self.content_separator_line.setFrameShape(QtWidgets.QFrame.HLine)
        self.content_separator_line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.content_separator_line.setObjectName("content_separator_line")
        self.verticalLayout_31.addWidget(self.content_separator_line)
        self.target_user_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.target_user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.target_user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.target_user_frame.setObjectName("target_user_frame")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.target_user_frame)
        self.verticalLayout_33.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_33.setSpacing(3)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.commented_title_2 = QtWidgets.QFrame(self.target_user_frame)
        self.commented_title_2.setStyleSheet("border:2px solid  rgb(59, 59, 59);")
        self.commented_title_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.commented_title_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.commented_title_2.setObjectName("commented_title_2")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.commented_title_2)
        self.horizontalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_20.setSpacing(3)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.commented_label = QtWidgets.QLabel(self.commented_title_2)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.commented_label.setFont(font)
        self.commented_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.commented_label.setAlignment(QtCore.Qt.AlignCenter)
        self.commented_label.setObjectName("commented_label")
        self.horizontalLayout_20.addWidget(self.commented_label)
        self.verticalLayout_33.addWidget(self.commented_title_2)
        self.comments_progressbar = QtWidgets.QProgressBar(self.target_user_frame)
        self.comments_progressbar.setStyleSheet("QProgressBar {\n"
"     border: 1px solid grey;\n"
"     border-radius: 2px;\n"
"     color:white;\n"
"     background-color: rgb(79, 79, 79);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"     background-color: rgb(255, 23, 96);\n"
"     width: 20px;\n"
" }\n"
"")
        self.comments_progressbar.setProperty("value", 24)
        self.comments_progressbar.setAlignment(QtCore.Qt.AlignCenter)
        self.comments_progressbar.setObjectName("comments_progressbar")
        self.verticalLayout_33.addWidget(self.comments_progressbar)
        self.comment_listwidget = QtWidgets.QListWidget(self.target_user_frame)
        font = QtGui.QFont()
        font.setFamily("Segoe UI Semibold")
        font.setBold(True)
        font.setWeight(75)
        self.comment_listwidget.setFont(font)
        self.comment_listwidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.comment_listwidget.setTabKeyNavigation(False)
        self.comment_listwidget.setWordWrap(True)
        self.comment_listwidget.setObjectName("comment_listwidget")
        item = QtWidgets.QListWidgetItem()
        self.comment_listwidget.addItem(item)
        self.verticalLayout_33.addWidget(self.comment_listwidget)
        self.verticalLayout_31.addWidget(self.target_user_frame)
        self.footer_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.footer_frame.setMaximumSize(QtCore.QSize(16777215, 20))
        self.footer_frame.setStyleSheet("border-radius:2px;")
        self.footer_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.footer_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_frame.setObjectName("footer_frame")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout(self.footer_frame)
        self.verticalLayout_34.setContentsMargins(-1, 0, 0, 0)
        self.verticalLayout_34.setSpacing(2)
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.grip_label = QtWidgets.QLabel(self.footer_frame)
        self.grip_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.grip_label.setObjectName("grip_label")
        self.verticalLayout_34.addWidget(self.grip_label)
        self.verticalLayout_31.addWidget(self.footer_frame)
        self.horizontalLayout_18.addWidget(self.progress_and_status_frame)
        self.line = QtWidgets.QFrame(self.body_frame)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_18.addWidget(self.line)
        self.logged_user_frame = QtWidgets.QFrame(self.body_frame)
        self.logged_user_frame.setMaximumSize(QtCore.QSize(400, 16777215))
        self.logged_user_frame.setAutoFillBackground(False)
        self.logged_user_frame.setStyleSheet("background-color:rgb(35,35,35);")
        self.logged_user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.logged_user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.logged_user_frame.setObjectName("logged_user_frame")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self.logged_user_frame)
        self.verticalLayout_35.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.user_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.user_frame.setStyleSheet("border: 1px solid grey;")
        self.user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.user_frame.setObjectName("user_frame")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout(self.user_frame)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.user_avatar = QtWidgets.QLabel(self.user_frame)
        self.user_avatar.setMaximumSize(QtCore.QSize(50, 50))
        self.user_avatar.setStyleSheet("border:2px solid  rgb(17, 120, 255);")
        self.user_avatar.setText("")
        self.user_avatar.setPixmap(QtGui.QPixmap("rach1.jpg"))
        self.user_avatar.setScaledContents(True)
        self.user_avatar.setObjectName("user_avatar")
        self.horizontalLayout_21.addWidget(self.user_avatar)
        self.username = QtWidgets.QLabel(self.user_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.username.setFont(font)
        self.username.setStyleSheet("color: rgb(173, 173, 173);\n"
"border:none;")
        self.username.setWordWrap(True)
        self.username.setObjectName("username")
        self.horizontalLayout_21.addWidget(self.username)
        self.verticalLayout_35.addWidget(self.user_frame)
        self.live_update_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.live_update_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.live_update_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.live_update_frame.setObjectName("live_update_frame")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.live_update_frame)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.followers_frame = QtWidgets.QFrame(self.live_update_frame)
        self.followers_frame.setStyleSheet("background-color:none;")
        self.followers_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.followers_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.followers_frame.setObjectName("followers_frame")
        self.verticalLayout_36 = QtWidgets.QVBoxLayout(self.followers_frame)
        self.verticalLayout_36.setContentsMargins(-1, 2, 2, 2)
        self.verticalLayout_36.setObjectName("verticalLayout_36")
        self.followers_label = QtWidgets.QLabel(self.followers_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.followers_label.setFont(font)
        self.followers_label.setStyleSheet("color: rgb(255, 23, 96);")
        self.followers_label.setObjectName("followers_label")
        self.verticalLayout_36.addWidget(self.followers_label)
        self.follower_count = QtWidgets.QLabel(self.followers_frame)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.follower_count.setFont(font)
        self.follower_count.setStyleSheet("color: rgb(136, 136, 136);")
        self.follower_count.setObjectName("follower_count")
        self.verticalLayout_36.addWidget(self.follower_count)
        self.horizontalLayout_3.addWidget(self.followers_frame)
        self.follower_live_statistics = QtWidgets.QFrame(self.live_update_frame)
        self.follower_live_statistics.setStyleSheet("background-color:none;")
        self.follower_live_statistics.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.follower_live_statistics.setFrameShadow(QtWidgets.QFrame.Raised)
        self.follower_live_statistics.setObjectName("follower_live_statistics")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.follower_live_statistics)
        self.verticalLayout.setContentsMargins(3, 0, 9, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.stats_title = QtWidgets.QLabel(self.follower_live_statistics)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.stats_title.setFont(font)
        self.stats_title.setStyleSheet("color: rgb(236, 236, 236);")
        self.stats_title.setAlignment(QtCore.Qt.AlignCenter)
        self.stats_title.setObjectName("stats_title")
        self.verticalLayout.addWidget(self.stats_title)
        self.stat_indicator = QtWidgets.QLabel(self.follower_live_statistics)
        self.stat_indicator.setMaximumSize(QtCore.QSize(16777215, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.stat_indicator.setFont(font)
        self.stat_indicator.setStyleSheet("color: rgb(136, 136, 136);")
        self.stat_indicator.setText("")
        self.stat_indicator.setPixmap(QtGui.QPixmap("../../Downloads/decrease.png"))
        self.stat_indicator.setScaledContents(False)
        self.stat_indicator.setAlignment(QtCore.Qt.AlignCenter)
        self.stat_indicator.setObjectName("stat_indicator")
        self.verticalLayout.addWidget(self.stat_indicator)
        self.gaiin_lost = QtWidgets.QLabel(self.follower_live_statistics)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.gaiin_lost.setFont(font)
        self.gaiin_lost.setStyleSheet("color: rgb(136, 136, 136);")
        self.gaiin_lost.setAlignment(QtCore.Qt.AlignCenter)
        self.gaiin_lost.setObjectName("gaiin_lost")
        self.verticalLayout.addWidget(self.gaiin_lost)
        self.horizontalLayout_3.addWidget(self.follower_live_statistics)
        self.following_frame = QtWidgets.QFrame(self.live_update_frame)
        self.following_frame.setStyleSheet("background-color:none;")
        self.following_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.following_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.following_frame.setObjectName("following_frame")
        self.verticalLayout_37 = QtWidgets.QVBoxLayout(self.following_frame)
        self.verticalLayout_37.setContentsMargins(9, 2, 2, 2)
        self.verticalLayout_37.setObjectName("verticalLayout_37")
        self.following_label = QtWidgets.QLabel(self.following_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.following_label.setFont(font)
        self.following_label.setStyleSheet("color:rgb(17, 120, 255);\n"
"border:none;\n"
"")
        self.following_label.setAlignment(QtCore.Qt.AlignCenter)
        self.following_label.setObjectName("following_label")
        self.verticalLayout_37.addWidget(self.following_label)
        self.following_count = QtWidgets.QLabel(self.following_frame)
        self.following_count.setStyleSheet("color: rgb(180, 180, 180);")
        self.following_count.setAlignment(QtCore.Qt.AlignCenter)
        self.following_count.setObjectName("following_count")
        self.verticalLayout_37.addWidget(self.following_count)
        self.horizontalLayout_3.addWidget(self.following_frame)
        self.verticalLayout_35.addWidget(self.live_update_frame)
        self.content_separator_line_2 = QtWidgets.QFrame(self.logged_user_frame)
        self.content_separator_line_2.setMaximumSize(QtCore.QSize(396, 1))
        self.content_separator_line_2.setStyleSheet("\n"
"background-color: rgb(255, 23, 96);")
        self.content_separator_line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.content_separator_line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.content_separator_line_2.setObjectName("content_separator_line_2")
        self.verticalLayout_35.addWidget(self.content_separator_line_2)
        self.status_and_profile_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.status_and_profile_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.status_and_profile_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.status_and_profile_frame.setObjectName("status_and_profile_frame")
        self.verticalLayout_38 = QtWidgets.QVBoxLayout(self.status_and_profile_frame)
        self.verticalLayout_38.setObjectName("verticalLayout_38")
        self.status_listwidget = QtWidgets.QListWidget(self.status_and_profile_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        font.setBold(False)
        font.setWeight(50)
        self.status_listwidget.setFont(font)
        self.status_listwidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.status_listwidget.setTabKeyNavigation(False)
        self.status_listwidget.setWordWrap(True)
        self.status_listwidget.setObjectName("status_listwidget")
        item = QtWidgets.QListWidgetItem()
        self.status_listwidget.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.status_listwidget.addItem(item)
        self.verticalLayout_38.addWidget(self.status_listwidget)
        self.verticalLayout_35.addWidget(self.status_and_profile_frame)
        self.add_hashtag_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.add_hashtag_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.add_hashtag_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.add_hashtag_frame.setObjectName("add_hashtag_frame")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.add_hashtag_frame)
        self.verticalLayout_39.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_39.setSpacing(3)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.hashtag_input = QtWidgets.QTextEdit(self.add_hashtag_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.hashtag_input.setFont(font)
        self.hashtag_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(59, 59, 59);")
        self.hashtag_input.setObjectName("hashtag_input")
        self.verticalLayout_39.addWidget(self.hashtag_input)
        self.verticalLayout_35.addWidget(self.add_hashtag_frame)
        self.add_comments_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.add_comments_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.add_comments_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.add_comments_frame.setObjectName("add_comments_frame")
        self.verticalLayout_40 = QtWidgets.QVBoxLayout(self.add_comments_frame)
        self.verticalLayout_40.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_40.setSpacing(3)
        self.verticalLayout_40.setObjectName("verticalLayout_40")
        self.add_comments_input = QtWidgets.QTextEdit(self.add_comments_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.add_comments_input.setFont(font)
        self.add_comments_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(255, 23, 96);")
        self.add_comments_input.setObjectName("add_comments_input")
        self.verticalLayout_40.addWidget(self.add_comments_input)
        self.verticalLayout_35.addWidget(self.add_comments_frame)
        self.target_usernames_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.target_usernames_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.target_usernames_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.target_usernames_frame.setObjectName("target_usernames_frame")
        self.verticalLayout_41 = QtWidgets.QVBoxLayout(self.target_usernames_frame)
        self.verticalLayout_41.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_41.setSpacing(3)
        self.verticalLayout_41.setObjectName("verticalLayout_41")
        self.targetusernames_input = QtWidgets.QTextEdit(self.target_usernames_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.targetusernames_input.setFont(font)
        self.targetusernames_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(59, 59, 59);")
        self.targetusernames_input.setObjectName("targetusernames_input")
        self.verticalLayout_41.addWidget(self.targetusernames_input)
        self.verticalLayout_35.addWidget(self.target_usernames_frame)
        self.start_pause_button = QtWidgets.QFrame(self.logged_user_frame)
        self.start_pause_button.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.start_pause_button.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.start_pause_button.setFrameShadow(QtWidgets.QFrame.Raised)
        self.start_pause_button.setObjectName("start_pause_button")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.start_pause_button)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.start_button = QtWidgets.QPushButton(self.start_pause_button)
        self.start_button.setMaximumSize(QtCore.QSize(200, 16777215))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.start_button.setFont(font)
        self.start_button.setStyleSheet("*{\n"
"background-color: rgb(255, 23, 96);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgb(106, 59, 248);\n"
"}")
        self.start_button.setObjectName("start_button")
        self.horizontalLayout_2.addWidget(self.start_button)
        self.logout_button = QtWidgets.QPushButton(self.start_pause_button)
        self.logout_button.setMaximumSize(QtCore.QSize(200, 16777215))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.logout_button.setFont(font)
        self.logout_button.setStyleSheet("*{\n"
" background-color: rgb(106, 59, 248);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"\n"
"    background-color: rgb(255, 23, 96);\n"
"}")
        self.logout_button.setObjectName("logout_button")
        self.horizontalLayout_2.addWidget(self.logout_button)
        self.verticalLayout_35.addWidget(self.start_pause_button)
        self.horizontalLayout_18.addWidget(self.logged_user_frame)
        self.verticalLayout_29.addWidget(self.body_frame)
        self.horizontalLayout.addWidget(self.main_frame)
        self.stackedWidget.addWidget(self.bot_page)
        self.verticalLayout_43.addWidget(self.stackedWidget)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.stackedWidget.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.connection_label.setText(_translate("MainWindow", "Connecting to database ..."))
        self.label_4.setText(_translate("MainWindow", "Natalie Bot"))
        self.username_input.setPlaceholderText(_translate("MainWindow", "Enter your username"))
        self.password_input.setPlaceholderText(_translate("MainWindow", "Enter your password"))
        self.pushButton.setText(_translate("MainWindow", "Login"))
        self.grip_label_4.setText(_translate("MainWindow", "can\'t resize a login window"))
        self.label.setText(_translate("MainWindow", "Natalie Bot"))
        self.liked_label.setText(_translate("MainWindow", "Liked Today"))
        __sortingEnabled = self.like_listWidget.isSortingEnabled()
        self.like_listWidget.setSortingEnabled(False)
        item = self.like_listWidget.item(0)
        item.setText(_translate("MainWindow", "like this user post on 12 june 2020"))
        self.like_listWidget.setSortingEnabled(__sortingEnabled)
        self.commented_label.setText(_translate("MainWindow", "Commented Today"))
        __sortingEnabled = self.comment_listwidget.isSortingEnabled()
        self.comment_listwidget.setSortingEnabled(False)
        item = self.comment_listwidget.item(0)
        item.setText(_translate("MainWindow", "like this user post on 12 june 2020"))
        self.comment_listwidget.setSortingEnabled(__sortingEnabled)
        self.grip_label.setText(_translate("MainWindow", "Grip to Resize window"))
        self.username.setText(_translate("MainWindow", "hey i\'m natalie \n"
""))
        self.followers_label.setText(_translate("MainWindow", "Followers"))
        self.follower_count.setText(_translate("MainWindow", "5000000"))
        self.stats_title.setText(_translate("MainWindow", "live follower stats"))
        self.gaiin_lost.setText(_translate("MainWindow", "Gained 50 today"))
        self.following_label.setText(_translate("MainWindow", "Following"))
        self.following_count.setText(_translate("MainWindow", "5000"))
        __sortingEnabled = self.status_listwidget.isSortingEnabled()
        self.status_listwidget.setSortingEnabled(False)
        item = self.status_listwidget.item(0)
        item.setText(_translate("MainWindow", "logging you in"))
        item = self.status_listwidget.item(1)
        item.setText(_translate("MainWindow", "Getting recent hashtag posts"))
        self.status_listwidget.setSortingEnabled(__sortingEnabled)
        self.hashtag_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.hashtag_input.setPlaceholderText(_translate("MainWindow", "Enter or paste hashtags"))
        self.add_comments_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.add_comments_input.setPlaceholderText(_translate("MainWindow", "Enter or paste comments"))
        self.targetusernames_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.targetusernames_input.setPlaceholderText(_translate("MainWindow", "Enter or paste target usernames"))
        self.start_button.setText(_translate("MainWindow", "Start Bot"))
        self.logout_button.setText(_translate("MainWindow", "logout"))
